@@ -2,7 +2,7 @@ import ctre
 import math
 
 from robotpy_toolkit_7407.utils.units import radians
-from robotpy_toolkit_7407.sensors.gyro import Gyro
+from robotpy_toolkit_7407.sensors.gyro.base_gyro import Gyro
 
 
 class PigeonIMUGyro_Wrapper(Gyro):
